@@ -22,7 +22,10 @@ describe 'swift::proxy::cache' do
 
         it { is_expected.to contain_swift_proxy_config('filter:cache/use').with_value('egg:swift#memcache') }
         it { is_expected.to contain_swift_proxy_config('filter:cache/memcache_servers').with_value('127.0.0.1:11211') }
-        it { is_expected.to contain_swift_proxy_config('filter:cache/tls_enabled').with_value(false) }
+        it { is_expected.to contain_swift_proxy_config('filter:cache/tls_enabled').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_swift_proxy_config('filter:cache/tls_cafile').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_swift_proxy_config('filter:cache/tls_certfile').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_swift_proxy_config('filter:cache/tls_keyfile').with_value('<SERVICE DEFAULT>') }
         it { is_expected.to contain_swift_proxy_config('filter:cache/memcache_max_connections').with_value(2) }
       end
 
