@@ -12,17 +12,12 @@ describe 'swift::proxy::ceilometer' do
 
     let :params do
       {
-        :password => 'swiftpassword'
+        :password              => 'swiftpassword',
+        :default_transport_url => 'rabbit://user_1:user_1_passw@1.1.1.1:5673/rabbit',
       }
     end
 
     describe "when using default parameters" do
-      before :each do
-        params.merge!({
-          :default_transport_url => 'rabbit://user_1:user_1_passw@1.1.1.1:5673/rabbit',
-        })
-      end
-
       it { is_expected.to contain_swift_proxy_config('filter:ceilometer/password').with_value('swiftpassword').with_secret(true) }
       it { is_expected.to contain_swift_proxy_config('filter:ceilometer/paste.filter_factory').with_value('ceilometermiddleware.swift:filter_factory') }
       it { is_expected.to contain_swift_proxy_config('filter:ceilometer/url').with_value('rabbit://user_1:user_1_passw@1.1.1.1:5673/rabbit').with_secret(true) }
@@ -30,30 +25,37 @@ describe 'swift::proxy::ceilometer' do
       it { is_expected.to contain_swift_proxy_config('filter:ceilometer/topic').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_swift_proxy_config('filter:ceilometer/control_exchange').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_swift_proxy_config('filter:ceilometer/nonblocking_notify').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_swift_proxy_config('filter:ceilometer/extra_config_files').with_value('/etc/swift/ceilometer.conf') }
 
       it { is_expected.to contain_package('python-ceilometermiddleware').with(
         :ensure => 'present',
         :name   => platform_params[:ceilometermiddleware_package_name],
         :tag    => ['openstack', 'swift-support-package'],
       )}
+
+      it { is_expected.to contain_file('/etc/swift/ceilometer.conf').with(
+        :ensure => 'file',
+        :owner  => 'root',
+        :group  => 'swift',
+        :mode   => '0640',
+      )}
     end
 
     describe "when overriding default parameters with rabbit driver" do
       before :each do
         params.merge!({
-          :default_transport_url => 'rabbit://user_1:user_1_passw@1.1.1.1:5673/rabbit',
-          :driver                => 'messagingv2',
-          :topic                 => 'notifications',
-          :control_exchange      => 'swift',
-          :nonblocking_notify    => true,
-          :ignore_projects       => ['services'],
-          :auth_url              => 'http://127.0.0.1:5000',
-          :auth_type             => 'password',
-          :project_domain_name   => 'Default',
-          :user_domain_name      => 'Default',
-          :project_name          => 'services',
-          :username              => 'swift',
-          :region_name           => 'region2'
+          :driver              => 'messagingv2',
+          :topic               => 'notifications',
+          :control_exchange    => 'swift',
+          :nonblocking_notify  => true,
+          :ignore_projects     => ['services', 'admin'],
+          :auth_url            => 'http://127.0.0.1:5000',
+          :auth_type           => 'password',
+          :project_domain_name => 'Default',
+          :user_domain_name    => 'Default',
+          :project_name        => 'services',
+          :username            => 'swift',
+          :region_name         => 'region2'
         })
       end
 
@@ -64,7 +66,7 @@ describe 'swift::proxy::ceilometer' do
         it { is_expected.to contain_swift_proxy_config('filter:ceilometer/topic').with_value('notifications') }
         it { is_expected.to contain_swift_proxy_config('filter:ceilometer/control_exchange').with_value('swift') }
         it { is_expected.to contain_swift_proxy_config('filter:ceilometer/nonblocking_notify').with_value('true') }
-        it { is_expected.to contain_swift_proxy_config('filter:ceilometer/ignore_projects').with_value(['services']) }
+        it { is_expected.to contain_swift_proxy_config('filter:ceilometer/ignore_projects').with_value('services,admin') }
         it { is_expected.to contain_swift_proxy_config('filter:ceilometer/auth_url').with_value('http://127.0.0.1:5000') }
         it { is_expected.to contain_swift_proxy_config('filter:ceilometer/auth_type').with_value('password') }
         it { is_expected.to contain_swift_proxy_config('filter:ceilometer/project_name').with_value('services') }
@@ -75,15 +77,7 @@ describe 'swift::proxy::ceilometer' do
         it { is_expected.to contain_swift_proxy_config('filter:ceilometer/region_name').with_value('region2') }
       end
 
-      context 'with default transport url' do
-        before do
-          params.merge!({ :default_transport_url => 'rabbit://user:pass@host:1234/virt' })
-        end
-
-        it { is_expected.to contain_swift_proxy_config('filter:ceilometer/url').with_value('rabbit://user:pass@host:1234/virt').with_secret(true) }
-      end
-
-      it { is_expected.to contain_oslo__messaging__rabbit('swift_proxy_config').with(
+      it { is_expected.to contain_oslo__messaging__rabbit('swift_ceilometer_config').with(
         :rabbit_ha_queues            => '<SERVICE DEFAULT>',
         :heartbeat_timeout_threshold => '<SERVICE DEFAULT>',
         :heartbeat_rate              => '<SERVICE DEFAULT>',
@@ -99,7 +93,6 @@ describe 'swift::proxy::ceilometer' do
         :kombu_failover_strategy     => '<SERVICE DEFAULT>',
         :kombu_compression           => '<SERVICE DEFAULT>',
       )}
-      it { is_expected.to contain_oslo__messaging__amqp('swift_proxy_config') }
 
       context 'with overridden rabbit ssl params' do
         before do
@@ -113,7 +106,7 @@ describe 'swift::proxy::ceilometer' do
             })
         end
 
-        it { is_expected.to contain_oslo__messaging__rabbit('swift_proxy_config').with(
+        it { is_expected.to contain_oslo__messaging__rabbit('swift_ceilometer_config').with(
           :rabbit_use_ssl     => true,
           :kombu_ssl_ca_certs => '/etc/ca.cert',
           :kombu_ssl_certfile => '/etc/certfile',
@@ -127,8 +120,7 @@ describe 'swift::proxy::ceilometer' do
     describe 'when system_scope is set' do
       before :each do
         params.merge!({
-          :default_transport_url => 'rabbit://user_1:user_1_passw@1.1.1.1:5673/rabbit',
-          :system_scope          => 'all'
+          :system_scope => 'all'
         })
       end
 
