@@ -9,7 +9,7 @@ describe 'swift::proxy::gatekeeper' do
       it { is_expected.to contain_swift_proxy_config('filter:gatekeeper/set log_name').with_value('gatekeeper') }
       it { is_expected.to contain_swift_proxy_config('filter:gatekeeper/set log_facility').with_value('LOG_LOCAL2') }
       it { is_expected.to contain_swift_proxy_config('filter:gatekeeper/set log_level').with_value('INFO') }
-      it { is_expected.to contain_swift_proxy_config('filter:gatekeeper/set log_headers').with_value('false') }
+      it { is_expected.to contain_swift_proxy_config('filter:gatekeeper/set log_headers').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_swift_proxy_config('filter:gatekeeper/set log_address').with_value('/dev/log') }
     end
 
@@ -19,6 +19,7 @@ describe 'swift::proxy::gatekeeper' do
           :shunt_inbound_x_timestamp   => true,
           :allow_reserved_names_header => false,
           :log_name                    => 'newgatekeeper',
+          :log_headers                 => false,
           :log_facility                => 'LOG_LOCAL3',
           :log_level                   => 'WARN',
         }
@@ -29,6 +30,7 @@ describe 'swift::proxy::gatekeeper' do
       it { is_expected.to contain_swift_proxy_config('filter:gatekeeper/set log_name').with_value('newgatekeeper') }
       it { is_expected.to contain_swift_proxy_config('filter:gatekeeper/set log_facility').with_value('LOG_LOCAL3') }
       it { is_expected.to contain_swift_proxy_config('filter:gatekeeper/set log_level').with_value('WARN') }
+      it { is_expected.to contain_swift_proxy_config('filter:gatekeeper/set log_headers').with_value(false) }
     end
   end
 
