@@ -7,19 +7,25 @@ describe 'swift::proxy::keystone' do
     describe 'with defaults' do
       it { is_expected.to contain_swift_proxy_config('filter:keystone/operator_roles').with_value('admin, SwiftOperator') }
       it { is_expected.to contain_swift_proxy_config('filter:keystone/reseller_prefix').with_value('AUTH_') }
+      it { is_expected.to contain_swift_proxy_config('filter:keystone/project_reader_roles').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_swift_proxy_config('filter:keystone/system_reader_roles').with_value('<SERVICE DEFAULT>') }
     end
 
     describe 'with parameter overrides' do
       let :params do
         {
-          :operator_roles      => 'foo',
-          :reseller_prefix     => 'SWIFT_',
-          :reseller_admin_role => 'ResellerAdmin'
+          :operator_roles       => 'foo',
+          :reseller_prefix      => 'SWIFT_',
+          :reseller_admin_role  => 'ResellerAdmin',
+          :project_reader_roles => ['SwiftProjectReader'],
+          :system_reader_roles  => ['SwiftSystemReader'],
         }
 
         it { is_expected.to contain_swift_proxy_config('filter:keystone/operator_roles').with_value('foo') }
         it { is_expected.to contain_swift_proxy_config('filter:keystone/reseller_prefix').with_value('SWIFT_') }
         it { is_expected.to contain_swift_proxy_config('filter:keystone/reseller_admin_role').with_value('ResellerAdmin') }
+        it { is_expected.to contain_swift_proxy_config('filter:keystone/project_reader_roles').with_value('SwiftProjectReader') }
+        it { is_expected.to contain_swift_proxy_config('filter:keystone/system_reader_roles').with_value('SwiftSystemReader') }
       end
     end
   end
