@@ -2,6 +2,12 @@ require 'spec_helper'
 
 describe 'swift::proxy::s3token' do
   shared_examples 'swift::proxy::s3token' do
+    let :params do
+      {
+        :password => 'swiftpassword'
+      }
+    end
+
     describe "when using default parameters" do
       it { is_expected.to contain_swift_proxy_config('filter:s3token/use').with_value('egg:swift#s3token') }
       it { is_expected.to contain_swift_proxy_config('filter:s3token/auth_uri').with_value('http://127.0.0.1:5000') }
@@ -13,15 +19,15 @@ describe 'swift::proxy::s3token' do
       it { is_expected.to contain_swift_proxy_config('filter:s3token/auth_type').with_value('password') }
       it { is_expected.to contain_swift_proxy_config('filter:s3token/username').with_value('swift') }
       it { is_expected.to contain_swift_proxy_config('filter:s3token/user_domain_id').with_value('default') }
-      it { is_expected.to contain_swift_proxy_config('filter:s3token/password').with_value('password').with_secret(true) }
+      it { is_expected.to contain_swift_proxy_config('filter:s3token/password').with_value('swiftpassword').with_secret(true) }
       it { is_expected.to contain_swift_proxy_config('filter:s3token/project_name').with_value('services') }
       it { is_expected.to contain_swift_proxy_config('filter:s3token/project_domain_id').with_value('default') }
       it { is_expected.to contain_swift_proxy_config('filter:s3token/system_scope').with_value('<SERVICE DEFAULT>') }
     end
 
     describe "when overriding default parameters" do
-      let :params do
-        {
+      before :each do
+        params.merge!({
           :auth_uri               => 'http://192.168.24.11:5000',
           :reseller_prefix        => 'SWIFT_',
           :delay_auth_decision    => true,
@@ -30,11 +36,10 @@ describe 'swift::proxy::s3token' do
           :auth_url               => 'http://192.168.24.11:5000',
           :auth_type              => 'password',
           :username               => 'swift',
-          :password               => 'swift',
           :project_name           => 'admin',
           :project_domain_id      => '12345',
           :user_domain_id         => '12345'
-        }
+        })
       end
 
       it { is_expected.to contain_swift_proxy_config('filter:s3token/auth_uri').with_value('http://192.168.24.11:5000') }
@@ -46,17 +51,17 @@ describe 'swift::proxy::s3token' do
       it { is_expected.to contain_swift_proxy_config('filter:s3token/auth_type').with_value('password') }
       it { is_expected.to contain_swift_proxy_config('filter:s3token/username').with_value('swift') }
       it { is_expected.to contain_swift_proxy_config('filter:s3token/user_domain_id').with_value('12345') }
-      it { is_expected.to contain_swift_proxy_config('filter:s3token/password').with_value('swift').with_secret(true) }
+      it { is_expected.to contain_swift_proxy_config('filter:s3token/password').with_value('swiftpassword').with_secret(true) }
       it { is_expected.to contain_swift_proxy_config('filter:s3token/project_name').with_value('admin') }
       it { is_expected.to contain_swift_proxy_config('filter:s3token/project_domain_id').with_value('12345') }
       it { is_expected.to contain_swift_proxy_config('filter:s3token/system_scope').with_value('<SERVICE DEFAULT>') }
     end
 
     describe 'when system_scope is set' do
-      let :params do
-        {
+      before :each do
+        params.merge!({
           :system_scope => 'all'
-        }
+        })
       end
 
       it { is_expected.to contain_swift_proxy_config('filter:s3token/project_name').with_value('<SERVICE DEFAULT>') }
