@@ -39,7 +39,7 @@ describe 'swift::storage::account' do
               :ensure   => (param_hash[:manage_service] && param_hash[:enabled]) ? 'running' : 'stopped',
               :enable   => param_hash[:enabled],
               :provider => nil,
-              :tag      => 'swift-service',
+              :tag      => ['swift-service', 'swift-account-service'],
             )
           end
         end
