@@ -58,15 +58,11 @@ describe 'swift::storage' do
       end
 
       let (:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :xinetd_available => true }
         when 'RedHat'
-          if facts[:operatingsystemmajrelease] > '8'
-            { :xinetd_available => false }
-          else
-            { :xinetd_available => true }
-          end
+          { :xinetd_available => false }
         end
       end
 
