@@ -3,7 +3,7 @@ require 'spec_helper'
 describe 'swift::xfs' do
   shared_examples 'swift::xfs' do
     ['xfsprogs', 'parted'].each do |present_package|
-      it { is_expected.to contain_package(present_package).with_ensure('present') }
+      it { is_expected.to contain_package(present_package).with_ensure('installed') }
     end
   end
 
