@@ -3,11 +3,11 @@ require 'spec_helper'
 describe 'swift::proxy::tempauth_account' do
   shared_examples 'swift::proxy::tempauth_account' do
     let :title do
-      '    user_admin_admin,    admin .admin .reseller_admin'
+      '    user_admin_admin,    adminpass .admin .reseller_admin'
     end
 
     describe 'when passing in a string containing "user_<account>_<user>, <key> .<group1> .<groupx>"' do
-      it { should contain_swift_proxy_config('filter:tempauth/user_admin_admin').with_value('admin .admin .reseller_admin') }
+      it { should contain_swift_proxy_config('filter:tempauth/user_admin_admin').with_value('adminpass .admin .reseller_admin').with_secret(true) }
     end
   end
 
