@@ -57,6 +57,14 @@ describe 'swift::storage::server' do
         :read_only       => false,
       )}
 
+      it { is_expected.to contain_file('/etc/swift/account-server.conf').with(
+        :ensure => 'file',
+        :owner  => 'root',
+        :group  => 'swift',
+        :mode   => '0640',
+        :tag    => 'swift-config-file'
+      )}
+
       it {
         is_expected.to contain_swift_account_config('DEFAULT/devices').with_value('/srv/node')
         is_expected.to contain_swift_account_config('DEFAULT/bind_ip').with_value('10.0.0.1')
@@ -90,6 +98,7 @@ describe 'swift::storage::server' do
         is_expected.to contain_swift_account_config('DEFAULT/log_statsd_sample_rate_factor').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_account_config('DEFAULT/log_statsd_metric_prefix').with_value('<SERVICE DEFAULT>')
 
+        is_expected.to contain_swift_account_config('DEFAULT/db_preallocation').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_account_config('account-auditor/').with_ensure('present')
         is_expected.to contain_swift_account_config('account-auditor/log_name').with_ensure('absent')
         is_expected.to contain_swift_account_config('account-replicator/').with_ensure('present')
@@ -232,6 +241,21 @@ describe 'swift::storage::server' do
         :read_only       => false,
       )}
 
+      it { is_expected.to contain_file('/etc/swift/container-server.conf').with(
+        :ensure => 'file',
+        :owner  => 'root',
+        :group  => 'swift',
+        :mode   => '0640',
+        :tag    => 'swift-config-file'
+      )}
+      it { is_expected.to contain_file('/etc/swift/container-sync-realms.conf').with(
+        :ensure => 'file',
+        :owner  => 'root',
+        :group  => 'swift',
+        :mode   => '0640',
+        :tag    => 'swift-config-file'
+      )}
+
       it {
         is_expected.to contain_swift_container_config('DEFAULT/devices').with_value('/srv/node')
         is_expected.to contain_swift_container_config('DEFAULT/bind_ip').with_value('10.0.0.1')
@@ -264,6 +288,7 @@ describe 'swift::storage::server' do
         is_expected.to contain_swift_container_config('DEFAULT/log_statsd_sample_rate_factor').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_container_config('DEFAULT/log_statsd_metric_prefix').with_value('<SERVICE DEFAULT>')
 
+        is_expected.to contain_swift_container_config('DEFAULT/db_preallocation').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_container_config('DEFAULT/allowed_sync_hosts').with_value('127.0.0.1')
         is_expected.to contain_swift_container_config('container-auditor/').with_ensure('present')
         is_expected.to contain_swift_container_config('container-auditor/log_name').with_ensure('absent')
@@ -418,6 +443,14 @@ describe 'swift::storage::server' do
         :read_only       => false,
       )}
 
+      it { is_expected.to contain_file('/etc/swift/object-server.conf').with(
+        :ensure => 'file',
+        :owner  => 'root',
+        :group  => 'swift',
+        :mode   => '0640',
+        :tag    => 'swift-config-file'
+      )}
+
       it {
         is_expected.to contain_swift_object_config('DEFAULT/devices').with_value('/srv/node')
         is_expected.to contain_swift_object_config('DEFAULT/bind_ip').with_value('10.0.0.1')
